import { ElMessage } from 'element-plus';
import request from '/@/utils/request';

/**
 * @summary 获取机组
 */
export const GetByBelongTypeAndBelongID = async (params, req: any = request) => {
	return req({
		url: '/Assets/EnginePump/Logic/GetByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * @summary 获取Catalog 过滤获取机组
 */
export const GetCatalogTreeListByBelongTypeAndBelongID = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetCatalogTreeListByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};
/**
 * @summary 获取设备树结构数据
 */
export const GetEquipmentTreeDataStd = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetTreeListByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，返回设备树结构数据
 * 报错时返回 undefined
 * @returns
 */
export const getEquipmentTreeDataStd = async (params, req: any = request) => {
	const res = await GetEquipmentTreeDataStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as [];
		return resData;
	} else {
		ElMessage.error('获取设备失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

/**
 * @summary 获取所有设备（非树结构）
 */
export const GetEquipmentListStd = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetTreeItemListByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，返回所有设备（非树结构）
 * 报错时返回 undefined
 * @returns
 */
export const getEquipmentListStd = async (params, req: any = request) => {
	const res = await GetEquipmentListStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as [];
		return resData;
	} else {
		ElMessage.error('获取所有设备失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

/**
 * @summary 获取设备树，通过 GroupID
 */
export const GetEquipmentTreeDataByGroupIDStd = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetTreeListByGroupID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，返回设备树，通过 GroupID
 * 报错时返回 undefined
 * @returns
 */
export const getEquipmentTreeDataByGroupIDStd = async (params, req: any = request) => {
	const res = await GetEquipmentTreeDataByGroupIDStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as [];
		return resData;
	} else {
		ElMessage.error('获取设备树失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

/**
 * @summary 获取设备
 */
export const GetMainTreeListByBelongTypeAndBelongIDStd = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetMainTreeListByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，返回设备（过滤掉 CatalogID 为 '0'）的情况
 * 报错时返回 undefined
 * @returns
 */
export const getMainTreeListByBelongTypeAndBelongIDStd = async (params, req: any = request) => {
	const res = await GetMainTreeListByBelongTypeAndBelongIDStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as [];
		return resData;
	} else {
		ElMessage.error('获取设备失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

/**
 * @summary 通过belongType，belongID 和 分类编码获取设备
 */
export const GetCatalogTreeItemListByBelongTypeAndBelongIDStd = async (params, req: any = request) => {
	return req({
		url: '/Assets/Equipment/Std/GetCatalogListByBelongTypeAndBelongID@V1.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，通过belongType，belongID 和 分类编码获取设备
 * 报错时返回 undefined
 * @returns
 */
export const getCatalogTreeItemListByBelongTypeAndBelongIDStd = async (params, req: any = request) => {
	const res = await GetCatalogTreeItemListByBelongTypeAndBelongIDStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as [];
		return resData;
	} else {
		ElMessage.error('获取设备失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

export interface MainEquipTree {
	ID: string;
	ParentID: string;
	GroupID: string;
	Name: string;
	NO: string;
	CatalogID: string;
	ModelType: string;
	Specification: string;
	SupplierID: string;
	Paras?: Record<string, unknown>;
	Flags: string[];
	TagName: string;
	SortCode: number;
	Description: string;
	Children: MainEquipTree[];
}
